OC.L10N.register(
    "lib",
    {
    "Files" : "Ifuyla",
    "Apps" : "Isnasen",
    "Settings" : "Iɣewwaṛen",
    "Log out" : "Senser",
    "Users" : "Iseqdacen",
    "Email" : "Imayl",
    "Phone" : "Tiliɣri",
    "Twitter" : "Twitter",
    "Website" : "Asmel web",
    "Address" : "Adresse",
    "About" : "Γef",
    "Help" : "Tallalt"
},
"nplurals=2; plural=(n != 1);");
